summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/3rdparty/libpng/pngrio.c
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/3rdparty/libpng/pngrio.c')
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/pngrio.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/pngrio.c b/tqtinterface/qt4/src/3rdparty/libpng/pngrio.c
index 0598231..2202712 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/pngrio.c
+++ b/tqtinterface/qt4/src/3rdparty/libpng/pngrio.c
@@ -11,7 +11,7 @@
* special handling are expected to write a function that has the same
* arguments as this and performs a similar function, but that possibly
* has a different input method. Note that you shouldn't change this
* function, but rather write a tqreplacement function and then make
* libpng use it at run time with png_set_read_fn(...).
*/
@@ -35,7 +35,7 @@ png_read_data(png_structp png_ptr, png_bytep data, png_size_t length)
#if !defined(PNG_NO_STDIO)
/* This is the function that does the actual reading of data. If you are
- not reading from a standard C stream, you should create a tqreplacement
+ not reading from a standard C stream, you should create a replacement
read_data function and use it at run time with png_set_read_fn(), rather
than changing the library. */
#ifndef USE_FAR_KEYWORD
@@ -11,7 +11,7 @@
* arguments as this and performs a similar function, but that possibly
* has a different input method. Note that you shouldn't change this
- * function, but rather write a tqreplacement function and then make
+ * function, but rather write a replacement function and then make
* libpng use it at run time with png_set_read_fn(...).
*/